summaryrefslogtreecommitdiff
path: root/config.default.php
diff options
context:
space:
mode:
authorFrederic Guillot <fred@kanboard.net>2015-06-07 22:17:50 -0400
committerFrederic Guillot <fred@kanboard.net>2015-06-07 22:17:50 -0400
commite22da9d32addefa8d739171febcf6f6d0c06ba7b (patch)
treeaffb9f8729ac9d4f07dd7f24dff39bfaa9cda0ff /config.default.php
parent4f32352fe62e47ad5ea760eb00493bdc061b2407 (diff)
Add Mailgun API as mail transport
Diffstat (limited to 'config.default.php')
-rw-r--r--config.default.php12
1 files changed, 10 insertions, 2 deletions
diff --git a/config.default.php b/config.default.php
index 99698420..e5fe4da3 100644
--- a/config.default.php
+++ b/config.default.php
@@ -1,6 +1,8 @@
<?php
-// Rename this file to config.php if you want to change the values
+/*******************************************************************/
+/* Rename this file to config.php if you want to change the values */
+/*******************************************************************/
// Enable/Disable debug
define('DEBUG', false);
@@ -14,7 +16,7 @@ define('FILES_DIR', 'data/files/');
// E-mail address for the "From" header (notifications)
define('MAIL_FROM', 'notifications@kanboard.local');
// Mail transport to use: "smtp", "sendmail", "mail" (PHP mail function), "postmark"
define('MAIL_TRANSPORT', 'mail');
// SMTP configuration to use when the "smtp" transport is chosen
@@ -30,6 +32,12 @@ define('MAIL_SENDMAIL_COMMAND', '/usr/sbin/sendmail -bs');
// Postmark API token (used to send emails through their API)
define('POSTMARK_API_TOKEN', '');
+// Mailgun API key (used to send emails through their API)
+define('MAILGUN_API_TOKEN', '');
+
+// Mailgun domain name
+define('MAILGUN_DOMAIN', '');
+
// Database driver: sqlite, mysql or postgres (sqlite by default)
define('DB_DRIVER', 'sqlite');
@@ -14,7 +16,7 @@ define('FILES_DIR', 'data/files/');
// E-mail address for the "From" header (notifications)
define('MAIL_FROM', 'notifications@kanboard.local');
-// Mail transport to use: "smtp", "sendmail", "mail" (PHP mail function), "postmark"
+// Mail transport available: "smtp", "sendmail", "mail" (PHP mail function), "postmark", "mailgun"
define('MAIL_TRANSPORT', 'mail');
// SMTP configuration to use when the "smtp" transport is chosen